@@ -1,9 +1,11 @@
 import asyncio
+from abc import ABC
 from datetime import datetime
 from typing import List, Optional, Sequence, Set
 
 from pydantic import BaseModel, validate_arguments
 
+from ..cache import cache
 from ..core import BaseClient
 from ..encoders import encode_query_params
 
@@ -36,7 +38,7 @@ class AlertsResponse(BaseModel):
         fields = {"meta": "_meta"}
 
 
-class BaseAlertsResource:
+class BaseAlertsResource(ABC):
     def __init__(self, client: BaseClient):
         self._client = client
 
@@ -101,6 +103,7 @@ class BaseAlertsResource:
 
 
 class AsyncAlertsResource(BaseAlertsResource):
+    @cache
     async def get(
         self,
         user_uuid: str,
@@ -120,6 +123,7 @@ class AsyncAlertsResource(BaseAlertsResource):
 
 
 class SyncAlertsResource(BaseAlertsResource):
+    @cache
     def get(
         self,
         user_uuid: str,
