@@ -1,9 +1,11 @@
 import asyncio
+from abc import ABC
 from datetime import datetime
 from typing import List, Optional, Sequence, Set
 
 from pydantic import BaseModel, validate_arguments
 
+from ..cache import cache
 from ..core import BaseClient
 from ..encoders import encode_query_params
 from ..types import AccountType, Currency
@@ -46,7 +48,7 @@ class BalancesResponse(BaseModel):
         fields = {"meta": "_meta"}
 
 
-class BaseBalancesResource:
+class BaseBalancesResource(ABC):
     def __init__(self, client: BaseClient):
         self._client = client
 
@@ -121,6 +123,7 @@ class BaseBalancesResource:
 
 
 class AsyncBalancesResource(BaseBalancesResource):
+    @cache
     async def get(
         self,
         user_uuid: str,
@@ -142,6 +145,7 @@ class AsyncBalancesResource(BaseBalancesResource):
 
 
 class SyncBalancesResource(BaseBalancesResource):
+    @cache
     def get(
         self,
         user_uuid: str,
