@@ -1,7 +1,9 @@
+from abc import ABC
 from typing import List
 
 from pydantic import BaseModel, validate_arguments
 
+from ..cache import cache
 from ..core import BaseClient
 from ..types import AccountType, Currency
 
@@ -28,7 +30,7 @@ class InstitutionsResponse(BaseModel):
         fields = {"meta": "_meta"}
 
 
-class BaseInstitutionsResource:
+class BaseInstitutionsResource(ABC):
     def __init__(self, client: BaseClient):
         self._client = client
 
@@ -42,10 +44,12 @@ class BaseInstitutionsResource:
 
 
 class AsyncInstitutionsResource(BaseInstitutionsResource):
+    @cache
     async def get(self, user_uuid: str) -> List[Institution]:
         return await self._get(user_uuid)
 
 
 class SyncInstitutionsResource(BaseInstitutionsResource):
+    @cache
     def get(self, user_uuid: str) -> List[Institution]:
         return self._client.run(self._get(user_uuid))
